@@ -35,37 +35,39 @@ poisson.MODpq.stnar <- function(b, W, gama, a, p, d, Z = NULL, TT, N, copula = "
   } else  cholR <- NULL   ##  end  if ( copula != "clayton" )  {
 
   for ( ti in 1:p) {
-    u <- rcopula(n, N, copula, corrtype, rho, dof, cholR )
+    u <- PNAR::rcopula(n, N, copula, corrtype, rho, dof, cholR)
     x <- Rfast::eachrow( log(u), -lambda[, ti], oper = "/" )
-    y[, ti] <- getN(x, tt = 1)
+    y[, ti] <- PNAR::getN(x, tt = 1)
     i <- 0
     while ( sum( is.na(y[, ti]) ) > 0 ) {
       i <- i + 2
-      u <- rcopula(i * 100 + n, N, copula, corrtype, rho, dof, cholR )
+      u <- PNAR::rcopula(i * 100 + n, N, copula, corrtype, rho, dof, cholR)
       x <- Rfast::eachrow( log(u), -lambda[, ti], oper = "/" )
-      y[, ti] <- getN(x, tt = 1)
+      y[, ti] <- PNAR::getN(x, tt = 1)
     }
     ca[, ti] <- exp( -gama * ( W %*% y[, ti] )^2 )
-    x <- u <- NULL
   }
 
   for ( ti in (p + 1):TT ) {
     X <- cbind(1, W %*% y[, (ti - 1):(ti - p)], y[, (ti - 1):(ti - p)], Z)
     lambda[, ti] <- X %*% b + ca[, ti - d] * W %*% y[, (ti - 1):(ti - p)] %*% a
-    u <- rcopula(n, N, copula, corrtype, rho, dof, cholR)
+    u <- PNAR::rcopula(n, N, copula, corrtype, rho, dof, cholR)
     x <- Rfast::eachrow( log(u), -lambda[, ti], oper = "/" )
-    y[, ti] <- getN(x, tt = 1)
+    y[, ti] <- PNAR::getN(x, tt = 1)
     i <- 0
     while ( sum( is.na(y[, ti]) ) > 0 ) {
       i <- i + 2
-      u <- rcopula(i * 100 + n, N, copula, corrtype, rho, dof, cholR )
+      u <- PNAR::rcopula(i * 100 + n, N, copula, corrtype, rho, dof, cholR)
       x <- Rfast::eachrow( log(u), -lambda[, ti], oper = "/" )
-      y[, ti] <- getN(x, tt = 1)
+      y[, ti] <- PNAR::getN(x, tt = 1)
     }
     ca[, ti] <- exp( -gama * ( W %*% y[, ti] )^2 )
-    x <- u <- NULL
   }
 
+  x <- u <- NULL
+
+  lambda <- ts( t(lambda) )
+  y <- ts( t(y) )
   list(p2R = p2R, lambda = lambda, y = y)
 }
 
